@@ -28,7 +28,6 @@
 #ifndef FROM_PROJ_CPP
 #define FROM_PROJ_CPP
 #endif
-#define LRU11_DO_NOT_DEFINE_OUT_OF_CLASS_METHODS
 
 #if defined(HAVE_LIBDL) && !defined(_GNU_SOURCE)
 // Required for dladdr() on Cygwin
@@ -53,13 +52,12 @@
 
 #include "proj_config.h"
 
+#ifdef _WIN32
 #if defined(WINAPI_FAMILY) && (WINAPI_FAMILY == WINAPI_FAMILY_APP)
 #define UWP 1
 #else
 #define UWP 0
 #endif
-
-#ifdef _WIN32
 #include <shlobj.h>
 #include <windows.h>
 #else
@@ -72,9 +70,6 @@
 
 //! @cond Doxygen_Suppress
 
-#define STR_HELPER(x) #x
-#define STR(x) STR_HELPER(x)
-
 using namespace NS_PROJ::internal;
 
 NS_PROJ_START
@@ -796,10 +791,9 @@ unsigned long long FileStdio::tell() {
 
 std::unique_ptr<File> FileStdio::open(PJ_CONTEXT *ctx, const char *filename,
                                       FileAccess access) {
-    auto fp = fopen(filename,
-                    access == FileAccess::READ_ONLY
-                        ? "rb"
-                        : access == FileAccess::READ_UPDATE ? "r+b" : "w+b");
+    auto fp = fopen(filename, access == FileAccess::READ_ONLY     ? "rb"
+                              : access == FileAccess::READ_UPDATE ? "r+b"
+                                                                  : "w+b");
     return std::unique_ptr<File>(fp ? new FileStdio(filename, ctx, fp)
                                     : nullptr);
 }
@@ -1824,6 +1818,17 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
         ctx->ca_bundle_path = ca_bundle_path;
     }
 
+    // Load default value for errorIfBestTransformationNotAvailableDefault
+    // from environment first
+    const char *proj_only_best_default = getenv("PROJ_ONLY_BEST_DEFAULT");
+    if (proj_only_best_default && proj_only_best_default[0] != '\0') {
+        ctx->warnIfBestTransformationNotAvailableDefault = false;
+        ctx->errorIfBestTransformationNotAvailableDefault =
+            ci_equal(proj_only_best_default, "ON") ||
+            ci_equal(proj_only_best_default, "YES") ||
+            ci_equal(proj_only_best_default, "TRUE");
+    }
+
     ctx->iniFileLoaded = true;
     auto file = std::unique_ptr<NS_PROJ::File>(
         reinterpret_cast<NS_PROJ::File *>(pj_open_lib_internal(
@@ -1883,6 +1888,12 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
                 }
             } else if (ca_bundle_path == nullptr && key == "ca_bundle_path") {
                 ctx->ca_bundle_path = value;
+            } else if (proj_only_best_default == nullptr &&
+                       key == "only_best_default") {
+                ctx->warnIfBestTransformationNotAvailableDefault = false;
+                ctx->errorIfBestTransformationNotAvailableDefault =
+                    ci_equal(value, "ON") || ci_equal(value, "YES") ||
+                    ci_equal(value, "TRUE");
             }
         }
 
